#[repr(C)]pub struct ShutdownSystem {
pub trader_id: TraderId,
pub component_id: Ustr,
pub reason: Option<String>,
pub command_id: UUID4,
pub ts_init: UnixNanos,
pub correlation_id: Option<UUID4>,
}Expand description
Represents a command to shut down a system and terminate the process.
Fields
trader_id: TraderIdThe trader ID associated with the command.
component_id: UstrThe component ID associated with the command.
reason: Option<String>The reason for the shutdown command.
command_id: UUID4The command ID.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was created.
correlation_id: Option<UUID4>The correlation ID, set when this command is correlated to another command or request.
Implementations